@@ -244,41 +244,33 @@ class TreeDB(BaseDB):
             raise DataError('未知的value_type, 类型：%s ,值：%s' % (str(type(value)), value))
         return self.exec_bs('bs_treedb_insert_property', prop, value, value_type, overwrite)
 
-    def insert_items(self, items: List[tuple], overwrite=True) -> int:
+    def insert_items(self, items: Union[List[tuple], dict], overwrite=True) -> int:
         """
         批量插入数据
         eg: db.open('MXSE', '1.SD', file='ccubase').insert_items([('mxlabel', 'test'), ('mxid', 123)])
+            db.open('MXSE', '1.SD', file='ccubase').insert_items({'mxlabel': 'test', 'mxid': 123})
 
         :param items: 插入的数据
         :param overwrite: 是否覆盖原值
         """
-        if not isinstance(items, list):
-            raise DataError('错误的数据类型，items应为列表')
-        data_list = list()
-        for item in items:
-            data_list.append({'name': item[0], 'value': item[1], 'valuetype': self._check_item(item)})
 
-        return self.exec_bs('bs_treedb_insert_propertys', data_list, overwrite)
+        return self.exec_bs('bs_treedb_insert_propertys', self._generation_items(items), overwrite)
 
-    def insert_key_items(self, items: List[tuple], key: str = None) -> str:
+    def insert_key_items(self, items: Union[List[tuple], dict], key: str = None) -> str:
         """
         批量插入子键及k,v
         eg: db.open('MXSE', '1.SD', file='ccubase').insert_key_items(
                                                     items=[('mxlabel', 'test'), ('mxid', 123)], key='key1')
+            db.open('MXSE', '1.SD', file='ccubase').insert_key_items(
+                                                    items={'mxlabel': 'test', 'mxid': 123}, key='key1')
 
         :param items: 插入的数据, 如果元组传入三个元素，将第三个元素当作数据类型（见文首type_map），如果只传入两个，则自动获取数据类型
         :param key: 子键名称,不传自动生成
         :return: 生成的子键
         """
-        if isinstance(items, tuple):
-            items = [items]
-        if not isinstance(items, list):
-            raise DataError('错误的数据类型，items应为列表')
-        items_list = list()
-        for item in items:
-            items_list.append({'name': item[0], 'value': item[1], 'valuetype': self._check_item(item)})
-        return self.exec_bs('bs_treedb_insert_key_and_properties', key or '', TRDB_OPKF_OPENEXIST, items_list,
-                            True)
+
+        return self.exec_bs('bs_treedb_insert_key_and_properties', key or '', TRDB_OPKF_OPENEXIST,
+                            self._generation_items(items), True)
 
     def delete(self, keys: Union[list, str, None] = None) -> None:
         """
