@@ -84,7 +84,7 @@ class DBError(MxBaseException):
 
     def __str__(self):
         if not self.msg:
-            msg = '数据库错误，错误码: %s' % self.err_code
+            msg = '数据库错误，错误码: %s, 错误原因: %s' % (self.err_code, error_dict.get(self.err_code))
         else:
             msg = '%s: 数据库错误, 错误码: %s, 错误原因: %s' % (self.msg, self.err_code, error_dict.get(self.err_code))
 
